@@ -73,6 +73,9 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 					Raw:          []byte(resToken),
 					RawV2:        []byte(fmt.Sprintf("%s:%s:%s", resEmail, resToken, resDomain)),
 				}
+				s1.ExtraData = map[string]string{
+					"rotation_guide": "https://howtorotate.com/docs/tutorials/atlassian/",
+				}
 
 				if verify {
 					client := s.getClient()
